==> haskell-pem-0.2.4-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pem
version: 0.2.4
id: pem-0.2.4-761SixZo8osHFkLYPacyd4
key: pem-0.2.4-761SixZo8osHFkLYPacyd4
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-pem
synopsis: Privacy Enhanced Mail (PEM) format reader and writer.
description:
    Privacy Enhanced Mail (PEM) format reader and writer. long description
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.PEM
hidden-modules: Data.PEM.Parser Data.PEM.Writer Data.PEM.Types
abi: a692a9a2433ebdf612b8104bfefe6a7a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/pem-0.2.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/pem-0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-pem
hs-libraries: HSpem-0.2.4-761SixZo8osHFkLYPacyd4
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    basement-0.0.7-IRcTCDmYoctGxt4FUYqdQc
    memory-0.14.16-JXoliazMy4LBu5xxL66kmR
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             basement-0.0.7-IRcTCDmYoctGxt4FUYqdQc=77aa457f5c07dcb3edd04711d3590241
             memory-0.14.16-JXoliazMy4LBu5xxL66kmR=ab65a51ef395f4cd2a78138a2eaca54b
haddock-interfaces: /usr/share/doc/haskell-pem/html/pem.haddock
haddock-html: /usr/share/doc/haskell-pem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pem-0.2.4-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pem
version: 0.2.4
id: pem-0.2.4-HBYfigYF9hUH17nFrUR1q8
key: pem-0.2.4-HBYfigYF9hUH17nFrUR1q8
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-pem
synopsis: Privacy Enhanced Mail (PEM) format reader and writer.
description:
    Privacy Enhanced Mail (PEM) format reader and writer. long description
category: Data
abi: cc46fbcdf8eba365327552ffcf35b144
exposed: True
exposed-modules:
    Data.PEM
hidden-modules: Data.PEM.Parser Data.PEM.Writer Data.PEM.Types
import-dirs: /usr/lib/ghc-8.4.2/site-local/pem-0.2.4
library-dirs: /usr/lib/ghc-8.4.2/site-local/pem-0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-pem
hs-libraries: HSpem-0.2.4-HBYfigYF9hUH17nFrUR1q8
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    basement-0.0.7-2rr6CUCXDXO23STP232Skz
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             basement-0.0.7-2rr6CUCXDXO23STP232Skz=b9469aed71b46ade42c22f303ffe0ad8
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=ed2d5adcedeb6833cc2a392fb853e830
haddock-interfaces: /usr/share/doc/haskell-pem/html/pem.haddock
haddock-html: /usr/share/doc/haskell-pem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
